<?php
/**
 * Plant functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * @link https://codex.wordpress.org/Plugin_API
 *
 * @package ENGOTHEME
 * @subpackage Plant
 * @since Plant 1.0
 */
define('PLANT', '1.0');

/**
 * Set up the content width value based on the theme's design.
 *
 * @see plant_fnc_content_width()
 *
 * @since Plant 1.0
 */
if (!isset($content_width)) {
    $content_width = 474;
}

function plant_fnc_content_width()
{
    $GLOBALS['content_width'] = apply_filters('plant_fnc_content_width', 810);
}

add_action('after_setup_theme', 'plant_fnc_content_width', 0);


if (!function_exists('plant_fnc_setup')) :
    /**
     * Plant setup.
     *
     * Set up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support post thumbnails.
     *
     * @since Plant 1.0
     */
    function plant_fnc_setup()
    {

        /*
         * Make Plant available for translation.
         *
         * Translations can be added to the /languages/ directory.
         * If you're building a theme based on Plant, use a find and
         * replace to change 'plant' to the name of your theme in all
         * template files.
         */
        load_theme_textdomain('plant', get_template_directory() . '/languages');

        // This theme styles the visual editor to resemble the theme style.

        // Default block styles
        add_theme_support('wp-block-styles');

        // Add RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');

        // Enable support for Post Thumbnails, and declare two sizes.
        add_theme_support('post-thumbnails');
        set_post_thumbnail_size(672, 372, true);

        add_editor_style();
        // This theme uses wp_nav_menu() in two locations.
        register_nav_menus(array(
            'primary' => esc_html__('Main menu', 'plant'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ));
        // add support woocommerce

        add_theme_support("woocommerce");
        /*
         * Enable support for Post Formats.
         * See https://codex.wordpress.org/Post_Formats
         */
        add_theme_support('post-formats', array(
            'aside', 'image', 'video', 'audio', 'quote', 'link', 'gallery',
        ));

        // This theme allows users to set a custom background.
        add_theme_support('custom-background', apply_filters('plant_fnc_custom_background_args', array(
            'default-color' => 'f5f5f5',
        )));


        // add support for display browser title
        add_theme_support('title-tag');
        // This theme uses its own gallery styles.
        add_filter('use_default_gallery_style', '__return_false');

        plant_fnc_get_load_plugins();

    }
endif; // plant_fnc_setup
add_action('after_setup_theme', 'plant_fnc_setup');


/**
 * Get Theme Option Value.
 * @param String $name : name of prameters
 */
function plant_fnc_theme_options($name, $default = false)
{

    // get the meta from the database
    $options = (get_option('pbr_theme_options')) ? get_option('pbr_theme_options') : null;


    // return the option if it exists
    if (isset($options[$name])) {
        return apply_filters('pbr_theme_options_$name', $options[$name]);
    }
    if (get_option($name)) {
        return get_option($name);
    }
    // return default if nothing else
    return apply_filters('pbr_theme_options_$name', $default);
}


//Update logo wordpress 4.5
function plantt_fnc_setup_logo()
{
    add_theme_support('custom-logo');
}

add_action('after_setup_theme', 'plantt_fnc_setup_logo');


/**
 * Require function for including 3rd plugins
 *
 */
require_once(get_template_directory() . '/inc/plugins/class-tgm-plugin-activation.php');

function plant_fnc_get_load_plugins()
{

    $plugins[] = (array(
        'name' => esc_html__('MetaBox', 'plant'), // The plugin name
        'slug' => 'meta-box', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));

    $plugins[] = (array(
        'name' => esc_html__('WooCommerce', 'plant'), // The plugin name
        'slug' => 'woocommerce', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));

    $plugins[] = (array(
        'name' => esc_html__('Contact Form 7', 'plant'), // The plugin name
        'slug' => 'contact-form-7', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));

    $plugins[] = (array(
        'name' => esc_html__('Slider Revolution', 'plant'),// The plugin name
        'slug' => 'revslider', // The plugin slug (typically the folder name)
        'required' => true,
        'source' => get_stylesheet_directory() . '/plugins/revslider.zip', // The plugin source
    ));

    $plugins[] = (array(
        'name' => esc_html__('WPBakery Page Builder', 'plant'),// The plugin name
        'slug' => 'js_composer', // The plugin slug (typically the folder name)
        'required' => true,
        'source' => get_stylesheet_directory() . '/plugins/js_composer.zip', // The plugin source
    ));

    $plugins[] = (array(
        'name' => esc_html__('WpOpal Framework For Themes', 'plant'),// The plugin name
        'slug' => 'pbrthemer', // The plugin slug (typically the folder name)
        'required' => true,
        'source' => get_stylesheet_directory() . '/plugins/pbrthemer.zip', // The plugin source
    ));

    $plugins[] = (array(
        'name' => esc_html__('YITH WooCommerce Wishlist', 'plant'), // The plugin name
        'slug' => 'yith-woocommerce-wishlist', // The plugin slug (typically the folder name)
        'required' => true
    ));
    $plugins[] = (array(
        'name' => esc_html__('Variation Swatches for WooCommerce ', 'plant'), // The plugin name
        'slug' => 'variation-swatches-for-woocommerce', // The plugin slug (typically the folder name)
        'required' => true
    ));

    tgmpa($plugins);
}

/**
 * Register three Plant widget areas.
 *
 * @since Plant 1.0
 */
function plant_fnc_registart_widgets_sidebars()
{

    register_sidebar(
        array(
            'name' => esc_html__('Sidebar Default', 'plant'),
            'id' => 'sidebar-default',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'plant'),
            'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
    if (class_exists('PbrThemerSetting') || class_exists('WooCommerce')):
        register_sidebar(
            array(
                'name' => esc_html__('Left Sidebar', 'plant'),
                'id' => 'sidebar-left',
                'description' => esc_html__('Appears on posts and pages in the sidebar.', 'plant'),
                'before_widget' => '<aside id="%1$s" class="widget widget-style  clearfix %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h3 class="widget-title"><span>',
                'after_title' => '</span></h3>',
            ));

        register_sidebar(
            array(
                'name' => esc_html__('Right Sidebar', 'plant'),
                'id' => 'sidebar-right',
                'description' => esc_html__('Appears on posts and pages in the sidebar.', 'plant'),
                'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h3 class="widget-title"><span>',
                'after_title' => '</span></h3>',
            ));

        register_sidebar(
            array(
                'name' => esc_html__('Blog Left Sidebar', 'plant'),
                'id' => 'blog-sidebar-left',
                'description' => esc_html__('Appears on posts and pages in the sidebar.', 'plant'),
                'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h3 class="widget-title"><span>',
                'after_title' => '</span></h3>',
            ));

        register_sidebar(
            array(
                'name' => esc_html__('Blog Right Sidebar', 'plant'),
                'id' => 'blog-sidebar-right',
                'description' => esc_html__('Appears on posts and pages in the sidebar.', 'plant'),
                'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h3 class="widget-title"><span>',
                'after_title' => '</span></h3>',
            ));
        register_sidebar(
            array(
                'name' => esc_html__('Content left for Header V4', 'plant'),
                'id' => 'header-content-left',
                'description' => esc_html__('Used for header v4', 'plant'),
                'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h3 class="widget-title"><span>',
                'after_title' => '</span></h3>',
            ));
    endif;
}

add_action('widgets_init', 'plant_fnc_registart_widgets_sidebars');

/**
 * Register Lato Google font for plant.
 *
 * @return string
 * @since Plant 1.0
 *
 */
function plant_fnc_font_url()
{

    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */

    $Roboto_Condensed = _x('on', 'Roboto Condensed font: on or off', 'plant');

    $dosis = _x('on', 'Dosis font: on or off', 'plant');

    $Roboto = _x('on', 'Dosis font: on or off', 'plant');

    if ('off' !== $Roboto_Condensed || 'off' !== $dosis) {
        $font_families = array();


        if ('off' !== $Roboto_Condensed) {
            $font_families[] = 'Roboto Condensed:300,300i,400,400i,700,700i';
        }

        if ('off' !== $Roboto) {
            $font_families[] = 'Roboto:300,300i,400,400i,700,700i';
        }

        if ('off' !== $dosis) {
            $font_families[] = 'Dosis:200,300,400,500,600,700';
        }
        $query_args = array(
            'family' => (implode('%7C', $font_families)),
            'subset' => urlencode('latin,latin-ext'),
        );

        $protocol = is_ssl() ? 'https:' : 'http:';
        $fonts_url = add_query_arg($query_args, $protocol . '//fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

/**
 * Enqueue scripts and styles for the front end.
 *
 * @since Plant 1.0
 */
function plant_fnc_scripts()
{
    // Add Lato font, used in the main stylesheet.
    wp_enqueue_style('plant-open-sans', plant_fnc_font_url(), array(), null);

    // Add Genericons font, used in the main stylesheet.
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '3.0.3');

    wp_enqueue_style('ionicons', get_template_directory_uri() . '/css/ionicons.min.css', array());
    wp_enqueue_style('Pe-icon', get_template_directory_uri() . '/css/Pe-icon-7-stroke.min.css', array());
    wp_enqueue_style('slick', get_template_directory_uri() . '/js/slick/slick.css', array());
    wp_enqueue_style('slick-theme', get_template_directory_uri() . '/js/slick/slick-theme.css', array());
    wp_enqueue_style('animation', get_template_directory_uri() . '/css/animation.css', array());

    if (isset($_GET['pbr-skin']) && $_GET['pbr-skin']) {
        $currentSkin = $_GET['pbr-skin'];
    } else {
        $currentSkin = str_replace('.css', '', plant_fnc_theme_options('skin', 'default'));
    }

    wp_enqueue_style('plant-style', get_template_directory_uri() . '/css/style.css');
    // Load the Internet Explorer specific stylesheet.
    wp_enqueue_style('plant-ie', get_template_directory_uri() . '/css/ie.css', array('plant-style'), '20131205');
    wp_style_add_data('plant-ie', 'conditional', 'lt IE 9');


    wp_enqueue_script('slick', get_template_directory_uri() . '/js/slick/slick.min.js', array('jquery'), '20150315', true);

    wp_enqueue_script('isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('jquery'), '20130402');

    wp_enqueue_script('countTo', get_template_directory_uri() . '/js/jquery.countTo.js', array('jquery'), '20130402');
    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '20130402');

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('plant-comment-reply');
    }

    if (is_singular() && wp_attachment_is_image()) {
        wp_enqueue_script('plant-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array('jquery'), '20130402');
    }


    wp_enqueue_script('pretty-photo', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', array(), false, true);

    wp_enqueue_style('pretty-Photo', get_template_directory_uri() . '/css/prettyPhoto.css');


    wp_register_script('plant-functions', get_template_directory_uri() . '/js/functions.js', array('jquery'), '20150315', true);

    wp_localize_script('plant-functions', 'plantAjax', array('ajaxurl' => esc_js(admin_url('admin-ajax.php'))));
    wp_enqueue_script('plant-functions');

}

add_action('wp_enqueue_scripts', 'plant_fnc_scripts');

/**
 * Enqueue Google fonts style to admin screen for custom header display.
 *
 * @since Plant 1.0
 */
function plant_fnc_admin_fonts()
{
    wp_enqueue_style('plant-lato', plant_fnc_font_url(), array(), null);
}

add_action('admin_print_scripts-appearance_page_custom-header', 'plant_fnc_admin_fonts');


/**
 * Implement rick meta box for post and page, custom post types. These 're used with metabox plugins
 */
if (is_admin()) {
    require_once(get_template_directory() . '/inc/admin/function.php');
    require_once(get_template_directory() . '/inc/admin/metabox/pagepost.php');
}


require_once(get_template_directory() . '/inc/customizer.php');
require_once(get_template_directory() . '/inc/function-post.php');
require_once(get_template_directory() . '/inc/function-unilty.php');
require_once(get_template_directory() . '/inc/functions-import.php');
require_once(get_template_directory() . '/inc/template.php');
require_once(get_template_directory() . '/inc/nav.php');
require_once(get_template_directory() . '/inc/offcanvas-menu.php');


/**
 * Check and load to support visual composer
 */
if (in_array('js_composer/js_composer.php', apply_filters('active_plugins', get_option('active_plugins'))) && class_exists('WPBakeryVisualComposerAbstract')) {
    require_once(get_template_directory() . '/inc/vendors/visualcomposer/class-vc-elements.php');
    require_once(get_template_directory() . '/inc/vendors/visualcomposer/class-vc-theme.php');
    require_once(get_template_directory() . '/inc/vendors/visualcomposer/function-vc.php');

}

/**
 * Check to support woocommerce
 */
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    add_theme_support('woocommerce');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/class-vc-woocommerce.php');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/class-woocommerce.php');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/function-hook.php');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/function-logic.php');
}

if (class_exists('PBR_User_Account')) {
    new PBR_User_Account();
}
if (class_exists('PBR_bootstrap_navwalker')) {
    class Bootstrap_navwalker extends PBR_bootstrap_navwalker
    {
        function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0)
        {
            $indent = ($depth) ? str_repeat("\t", $depth) : '';
            $li_attributes = '';
            $class_names = $value = '';

            $megacontent = '';
            if ($this->hasMega($item, $depth)) {

                $megacontent = $this->genMegaMenuByConfig($item, $depth);
                $class_names .= ' aligned-' . $item->alignment;
                $args->has_children = true;
            }

            $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args);
            $id = strlen($id) ? ' id="' . esc_attr($id) . '"' : '';

            $output .= $indent . '<li' . $id . $value . $class_names . $li_attributes . '>';

            $attributes = !empty($item->attr_title) ? ' title="' . esc_attr($item->attr_title) . '"' : '';
            $attributes .= !empty($item->target) ? ' target="' . esc_attr($item->target) . '"' : '';
            $attributes .= !empty($item->xfn) ? ' rel="' . esc_attr($item->xfn) . '"' : '';
            $attributes .= !empty($item->url) ? ' href="' . esc_url($item->url) . '"' : '';
            $attributes .= ($args->has_children) ? ' class="dropdown-toggle" ' : '';

            $hascaret = $this->hasMega($item, $depth);

            $class_icon = '';
            if (isset($item->class_icon) && !empty($item->class_icon)) {
                $class_icon = '<i class="' . $item->class_icon . '"></i>';
            } else {
                $class_icon = '';
            }

            $text_customize = '';
            if (isset($item->text_customize) && !empty($item->text_customize)) {
                switch ($item->text_customize) {
                    case 'text_new':
                        $text_customize = esc_html__('New', 'plant');
                        break;

                    case 'text_hot':
                        $text_customize = esc_html__('Hot', 'plant');
                        break;

                    case 'text_featured':
                        $text_customize = esc_html__('Featured', 'plant');
                        break;

                    default:
                        $text_customize = '';
                        break;
                }
                $text_customize = !empty($item->text_customize) ? '<span class="text-label ' . str_replace('_', '-', $item->text_customize) . '">' . $text_customize . '</span>' : '';
            }

            $item_output = $args->before;
            $item_output .= '<a' . $attributes . '>';
            $item_output .= $class_icon;
            $item_output .= $text_customize;
            $item_output .= $args->link_before . apply_filters('the_title', $item->title, $item->ID) . $args->link_after;
            $item_output .= ($args->has_children) || $hascaret ? ' <b class="caret"></b></a>' : '</a>';
            $item_output .= $args->after;

            $item_output .= $megacontent;

            $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);
        }
    }

}

function plant_change_submenu_class($menu)
{
    $menu = preg_replace('/ class="sub-menu"/', '/ class="sub-menu dropdown-menu " /', $menu);
    return $menu;
}

add_filter('wp_nav_menu', 'plant_change_submenu_class');

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328815&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
